#!/bin/bash

# Get today's date for our backup filename
backupDate=$(date +'%F')

# Enter backup directory
cd /home/tactical/rmmbackup || exit
echo "Moving to backup directory..."

# Clear old log files
rm -rf *.log
echo "Log files cleared..." | tee -a trmm-backup-$backupDate.log

# Display todays date
echo "Backup Log - Tactical RMM" | tee -a trmm-backup-$backupDate.log
echo $backupDate | tee -a trmm-backup-$backupDate.log

# Create tar of docker directory
echo "Creating a tar archive of your Tactical RMM backup parent folder..." | tee -a docker-$backupDate.log
tar -czvf $backupDate-backup-trmm.tar.gz /rmmbackup

echo "Uploading backup file to BackBlaze..." | tee -a trmm-backup-$backupDate.log
rclone copy $backupDate-backup-trmm.tar.gz b2:rgm-tacticalrmm-backup --progress >> trmm-backup-$backupDate.log 2>&1

# remove the tar file from the main home folder after it's copied
echo "Removing local backup cache..." | tee -a trmm-backup-$backupDate.log
rm -rf $backupDate-backup-trmm.tar.gz >> trmm-backup-$backupDate.log 2>&1

# Run System Update
echo "Running System Update..." | tee -a trmm-backup-$backupDate.log
apt update && apt upgrade -y && apt autoremove -y | tee -a trmm-backup-$backupDate.log

# Email log to an email address
# sendmail -s "Docker Backup Completed" rgmcewan@outlook.com < docker-$backupDate.log

# Email log to an email address using postfix
echo "Tacticall RMM Backup | Complete!" | tee -a trmm-backup-$backupDate.log
/usr/sbin/sendmail -t -v rgmcewan@outlook.com < trmm-backup-$backupDate.log